@@ -1,6 +1,6 @@
 import json
 from .SFAPI import Sobjects, query,restClient,jsonFile,utils,objectUtil,debugLogs,digitalCommerceUtil
-import logging
+import logging,time
 import simplejson,sys
 from operator import itemgetter
 from inspect import getmembers, isfunction
@@ -10,7 +10,6 @@ import colorama
 varsFile = 'confIcli.json'
 vars = None
 
-
 def readVars(field=None):
     global vars
     vars = jsonFile.read(varsFile)
@@ -64,17 +63,19 @@ def _queryAndPrint(q,fields=None,systemFields=True,nullFields=False):
 def option_readme(args):
     if '-h' in args:
         return
+    if '-hu' in args:
+        return
     
     print(f"""
     {utils.CYELLOW}Significant updates:{utils.CEND}
 
      - Changes in version 0.49.0
        Added {utils.CYELLOW}-auto{utils.CEND} to the log parsing. This options activates the debug logs automatically for the -loguser especified. If no -loguser is specified it will do it for the user used to authenticate with the org.  
-            {utils.CGREEN}InCli -logs -u DTI -tail -loguser username:onboarding@nosdti-parceiros.cs109.force.com -deletelogs -auto.{utils.CEND}
+            {utils.CGREEN}InCli -logs -u orgAlias -tail -loguser username:onboarding@nosdti-parceiros.cs109.force.com -deletelogs -auto.{utils.CEND}
             This command will start listening for new logs for user onboarding@nosdti-parceiros.cs109.force.com in DTI and parsing them in real time. 
                 -auto will activate the debug logs automatically, so the logs are collected without any configuration in Salesforce. 
                 -delete will delete the logs from the server as they are parsed. A local copy for the 
-            {utils.CGREEN}InCli -logs -u DTI -tail -deletelogs -auto.{utils.CEND}
+            {utils.CGREEN}InCli -logs -u orgAlias -tail -deletelogs -auto.{utils.CEND}
             This command will start listening for new logs for the user used to authenticate with the org. -auto and -deletelogs as usual.
 
             * Replace DTI by the correct alias for the org in your sfdx setup. 
@@ -90,12 +91,13 @@ def option_readme(args):
                 Adding this APEX line in the code will increase the accuracy of CPU Time: {utils.CGREEN}System.debug('*** getCpuTime() *** Measured: ' + Limits.getCpuTime());{utils.CEND}
      - {utils.CGREEN}cpuD{utils.CEND}: The CPU time delta from the previous time the CPU Time was parsed. 
      - {utils.CGREEN}Qt{utils.CEND}: Total queries performed executing the APEX program (user apex + managed pacakes apex). This field accurate. 
-     - {utils.CGREEN}Q{utils.CEND}: Total queries performed by the user APEX program. This field is almost accurate.
-     - {utils.CGREEN}Qcm{utils.CEND}: Total queries performed by the managed package. We do not have control when they appear. When it changes is accurate.
-     - {utils.CGREEN}Qe{utils.CEND}: Estimate queries performed by the managed package. This is an estimate for the manage package queries. Almost accurate. 
+     - {utils.CGREEN}Q{utils.CEND}: Total queries performed by the user APEX program. This field is almost accurate. When it is not empty is accurate. {utils.CYELLOW}Requires Apex Profiling = Finest.
+     - {utils.CGREEN}Qmp{utils.CEND}: Total queries performed by the managed package. We do not have control when they appear. Only when it is updated is accurate.
+     - {utils.CGREEN}Qe{utils.CEND}: Estimate queries performed by the managed package. This is an estimate for the manage package queries. Almost accurate, accurate when Q is not empty.
      - {utils.CGREEN}type{utils.CEND}: Type of log event.
      - {utils.CGREEN}line{utils.CEND}: the line in the APEX program. 
      - {utils.CGREEN}wait{utils.CEND}: time elapsed from the previous event. Typically is the time consumed by the APEX program or managed package between events.  
+                In some cases there are 2 values x-y. x is the time to the previous event, y is the time after the event. 
      - {utils.CGREEN}time{utils.CEND}: the time consumed executing the method. 
      - {utils.CGREEN}query{utils.CEND}: the total queries consumed bu the method. 
      - {utils.CGREEN}Call Stack{utils.CEND}:
@@ -107,10 +109,15 @@ def option_readme(args):
                     - The {utils.CGREEN}wait{utils.CEND} field is the total wait time for the method in the loop. 
     
     Times are rounded to the closest milisecond. 
+    - APEX Code = Fine is required to show the call stack with methods
+    - APEX Profiling = Finest
+    - Database = Info
+    - Workflow = Info
+
     """)
 
 def option_q(args):
-    if '-h' in args:
+    if '-hu' in args:
         help = f"""
         {utils.CYELLOW}-q "select..."{utils.CEND} query to execute. System Fields, such as LastModifiedDate, and null fields are not returned. 
             {utils.CYELLOW}-null{utils.CEND} - will print fields with null values
@@ -120,6 +127,8 @@ def option_q(args):
             {utils.CYELLOW}-fields all{utils.CEND} --> print in table format"""
         return help
 
+    if '-h' in args: return
+
     #else:
     q = getParam(args,'-q')
 
@@ -138,9 +147,9 @@ def option_q(args):
 def option_cc(args):
     colorama.just_fix_windows_console()
 
-    if '-h' in args:
+    if '-hu' in args:
         help = f"""
-        {utils.CYELLOW}-cc{utils.CEND}       {utils.CGREEN}InCli -u "Org alias" -cc {utils.CEND}
+        {utils.CYELLOW}-cc{utils.CEND}       {utils.CGREEN}InCli -u orgAlias -cc {utils.CEND}
             Checks the catalogs. Gets all catalogs, does a getOffers, getOfferDetails. Performs basketwithoutconfig and basket with config, if -basket is set. 
             {utils.CYELLOW}-code{utils.CEND} - Catalogue Code. does it for a single catalog. 
             {utils.CYELLOW}-list{utils.CEND} - List all the catalogues. 
@@ -148,6 +157,8 @@ def option_cc(args):
 
         return help
 
+    if '-h' in args: return
+
     connectionInit(args)
 
    # path = getParam(args,'-checkCatalogs')
@@ -170,9 +181,11 @@ def option_d(args):
     help = f"""
         {utils.CYELLOW}-d objectName{utils.CEND} --> Describe an object
             {utils.CYELLOW}-d objectName:fieldName{utils.CEND} --> describe a field in the object"""
-    if '-h' in args:
+    if '-hu' in args:
         return help    
 
+    if '-h' in args: return
+
     connectionInit(args)
 
     objectField = getParam(args,'-d')
@@ -194,10 +207,12 @@ def option_d(args):
         print(simplejson.dumps(sibbling, indent=4))
 
 def option_l(args):
-    if '-h' in args:
+    if '-hu' in args:
         help = f"""
         {utils.CYELLOW}-l{utils.CEND} --> current org limits consuptions. """
         return help
+    if '-h' in args: return
+    
     connectionInit(args)
     action = '/services/data/v51.0/limits'
     res = restClient.callAPI(action)
@@ -221,7 +236,7 @@ def option_l(args):
     utils.printFormated(records)
 
 def option_o(args):
-    if '-h' in args:
+    if '-hu' in args:
         help = f"""
         {utils.CYELLOW}-o{utils.CEND} --> List all Objects
             {utils.CYELLOW}-name objectName{utils.CEND}  --> get one row from the object
@@ -229,7 +244,9 @@ def option_o(args):
             {utils.CYELLOW}-like name{utils.CEND} --> where the Name contains the substring name"""
 
         return help
-        
+
+    if '-h' in args: return
+      
     connectionInit(args)
 
     if '-name' in args:
@@ -281,9 +298,13 @@ def option_o(args):
 
 def option_default(args):
     help = f"""
-        {utils.CYELLOW}-default:set key value{utils.CEND} --> defaults the specified key-value
+        {utils.CYELLOW}-default  {utils.CEND}  --> displays the current default values. 
+        {utils.CYELLOW}-default:set key value{utils.CEND} --> defaults the specified key-value. When set as default, if the command does not include the parameter it will pick the default value
         {utils.CYELLOW}-default:del key  {utils.CEND}  --> deletes the default
-        {utils.CYELLOW}-default:get key  {utils.CEND}  --> displays the current value"""
+            {utils.CYELLOW}Defaultable u{utils.CEND}: Can be set to a default value --> {utils.CGREEN}InCli -default:set u collote@acme.com {utils.CEND} or {utils.CGREEN}InCli -default:set u orgAlias {utils.CEND} 
+            {utils.CYELLOW}Defaultable loguser{utils.CEND}: Can be set to default. {utils.CGREEN}InCli -default:set loguser "Alias:TheCollote"{utils.CEND}"""
+
+    if '-hu' in args: return
 
     if '-h' in args:
         return help   
@@ -298,19 +319,32 @@ def option_default(args):
 
     if "-default:set" in args: 
         key = getParam(args,'-default:set',1)
+        if key == None:
+            print(f"{utils.CLIGHT_PURPLE}Parameter to set not specified.{utils.CEND}")
+            print(f"{utils.CYELLOW}-default:set key value {utils.CEND}" )
+            return        
         value = getParam(args,'-default:set',2)
+        if value == None:
+            print(f"{utils.CLIGHT_PURPLE}Value to set not specified.{utils.CEND}")
+            print(f"{utils.CYELLOW}-default:set key value {utils.CEND}" )
+            return        
         if key == None or value==None:
             print(help)
             return
 
         restClient.setConfigVar(key,value)
-        print(f"Default value for {key} is {value}")
+        print(f"Default value for {key} is {utils.CYELLOW}{value}{utils.CEND}")
 
-    if "-default:get" in args: 
-        key = getParam(args,'-default:get',1)
+    if "-default" in args: 
+        key = 'u' 
         value =restClient.getConfigVar(key)
-        print(f"Default value for {key} is {value}")
+        if value == None: value = 'Not set'
+        print(f"Default value for {key} is {utils.CYELLOW}{value}{utils.CEND}")
 
+        key = 'loguser' 
+        value =restClient.getConfigVar(key)
+        if value == None: value = 'Not set'
+        print(f"Default value for {key} is {utils.CYELLOW}{value}{utils.CEND}")
 #def option_history(args):
 #    return
 #    if '-h' in args:
@@ -325,27 +359,35 @@ def option_default(args):
 
 def option_logs(args):
     help = f"""
-        {utils.CYELLOW}-logs Id{utils.CEND} --> parse the log with the provided Id. No modifiers.
-        {utils.CYELLOW}-logs inputfile {utils.CEND}--> parses the file provided in the inputfile. {utils.CGREEN}InCli -logs -inputfile "path to file/xxxx.log"{utils.CEND} No modifiers.
-        {utils.CYELLOW}-logs store {utils.CEND}--> parses the files saved locally in order of creation(download) 
-            {utils.CYELLOW}-error {utils.CEND}--> parses the files saved locally and displays only the ones with errors. {utils.CGREEN}InCli -logs -store -error "{utils.CEND} 
-        {utils.CYELLOW}-logs -last X {utils.CEND}--> parses the last X logs. X as number.
+        {utils.CYELLOW}-logs Id{utils.CEND} --> parse the log with the provided Id. No modifiers. {utils.CGREEN}InCli -u orgAlias -logs 07L0Q00000N5sMkUAJ"{utils.CEND}
+
+        {utils.CYELLOW}-logs -inputfile {utils.CEND}--> parses the file provided in the inputfile. {utils.CGREEN}InCli -logs -inputfile "path to file/xxxx.log"{utils.CEND} 
+
+        {utils.CYELLOW}-logs -store {utils.CEND}--> parses the files saved locally in order of creation(download) {utils.CGREEN}InCli -logs -store {utils.CEND} 
+            {utils.CYELLOW}-error {utils.CEND}--> parses the files saved locally and displays only the ones with errors. {utils.CGREEN}InCli -logs -store -error {utils.CEND} 
+
+        {utils.CYELLOW}-logs -folder path {utils.CEND}--> parses the files saved locally in order of creation(download) {utils.CGREEN}InCli -logs -folder /a/b/.../ {utils.CEND} {utils.CBLINK}NEW{utils.CEND}
+
+        {utils.CYELLOW}-logs -last X {utils.CEND}--> parses the last X logs. X as number. {utils.CGREEN}InCli -u orgAlias -logs -last 10{utils.CEND}. Parses the last 10 logs in the org.
+            {utils.CYELLOW}-loguser field:value{utils.CEND}, filter the logs for the specified user. The user can be specified by any field in the User Object. 
+                {utils.CGREEN}-loguser Id:0053O000000IHneQAG, -loguser "name:Onboarding Site Guest User", -loguser Alias:John.Doe, -loguser FirstName:Onboarding, -loguser ProfileId:00e3O000000IHneQAG{utils.CEND}
+            {utils.CYELLOW}-where X {utils.CEND}--> the where clause for a query on the ApexLog object.  
+                {utils.CGREEN}InCli -logs -loguser Alias:John.Doe -where="Status<>'Success" -last 10" {utils.CEND} --> parses the last 10 logs for user John.Doe where the status is not Success
+            {utils.CYELLOW}-file {utils.CEND}--> creates 2 files for the parsed file, txt and html format. 
+            {utils.CYELLOW}-limitinfo {utils.CEND}--> prints the times when the limits (CPU, SOQL) are parsed.    
+
         {utils.CYELLOW}-logs -tail {utils.CEND}--> activelly parsers new debug logs as they are created.
             {utils.CYELLOW}-deletelogs {utils.CEND}--> as log files are processed, they are deleted from the server. The local copy remains. if -loguser is not provided it will default to your User.
             {utils.CYELLOW}-auto {utils.CEND}--> automaticallyu configures the collection of logs for -loguser. If no -loguser provided defaults to your user. {utils.CBLINK}NEW{utils.CEND}
             {utils.CYELLOW}-loguser field:value{utils.CEND}, filter the logs for the specified user. The user can be specified by any field in the User Object. 
-        {utils.CYELLOW}-logs{utils.CEND} --> lists log records in the org. 
-            {utils.CYELLOW}-limit X{utils.CEND}, where X specifies the number of logs to list. Default 50 max 50K
-                {utils.CGREEN}-logs -limit 1000{utils.CEND}, displays the last 1000 log records
-            Modifiers:
-            {utils.CYELLOW}-loguser field:value{utils.CEND}, filter the logs for the specified user. The user can be specified by any field in the User Object. 
-                {utils.CGREEN}-loguser Id:0053O000000IHneQAG, -loguser "name:Onboarding Site Guest User", -loguser Alias:John.Doe, -loguser FirstName:Onboarding, -loguser ProfileId:00e3O000000IHneQAG{utils.CEND}
-                {utils.CLIGHT_PURPLE}Defaultable loguser{utils.CEND}: Can be set to default. {utils.CGREEN}-default:set loguser "Alias:John.Doe{utils.CEND}"
-            {utils.CYELLOW}-where X {utils.CEND}--> the where clause for a query on the ApexLog object.  
-                {utils.CGREEN}InCli -logs -loguser Alias:John.Doe -where="Status<>'Success" -last 10" {utils.CEND} --> parses the last 10 logs for user John.Doe where the status is not Success
-            {utils.CYELLOW}-file {utils.CEND}--> creates 2 files for the parsed file, txt and html format. 
-            {utils.CYELLOW}-limitinfo {utils.CEND}--> prints the times when the limits (CPU, SOQL) are parsed.  """
+            {utils.CGREEN}InCli -u orgAlias -logs -tail -loguser username:user@acme.com -deletelogs -auto.{utils.CEND} This command will listen to the logs for the loguser specified and delete the logs from the org as they are parsed (local copy is kept)
 
+        {utils.CYELLOW}-logs{utils.CEND} --> lists log records in the org. Default 50 lines.  {utils.CGREEN}InCli -u orgAlias -logs {utils.CEND} 
+            {utils.CYELLOW}-auto{utils.CEND}, refreshes the view every couple of seconds.     {utils.CGREEN}InCli -u orgAlias -logs -auto {utils.CEND}  {utils.CBLINK}NEW{utils.CEND}
+            {utils.CYELLOW}-limit X{utils.CEND}, where X specifies the number of logs to list. Default 50 max 50K {utils.CGREEN}InCli -u orgAlias -logs -auto -limit 10{utils.CEND} """
+        
+
+    if '-hu' in args: return
 
     if '-h' in args:
         return help
@@ -355,6 +397,8 @@ def option_logs(args):
     limit = getParam(args,'-limit')    
     limitInfo = True if '-limitinfo' in args else False   
     auto = True if '-auto' in args else False   
+    folder = getParam(args,'-folder')    
+    is_folder  = True if '-folder' in args else False   
 
     level = getParam(args,'-level') 
     loguser = getParam(args,'-loguser') 
@@ -370,11 +414,17 @@ def option_logs(args):
     if loguser == None:
         loguser = restClient.getConfigVar('loguser')
 
-    if logId == None and last== None and inputfile==None and tail == False and store==False:
+    if logId == None and last== None and inputfile==None and tail == False and store==False and is_folder==False:
         connectionInit(args)
         lim = 50 if limit == None else limit
 
-        return debugLogs.printLogRecords(loguser=loguser,limit=lim,whereClause=whereClause)
+        if auto:
+            while True:
+                debugLogs.printLogRecords(loguser=loguser,limit=lim,whereClause=whereClause)
+                time.sleep(5)
+
+        else:
+            return debugLogs.printLogRecords(loguser=loguser,limit=lim,whereClause=whereClause)
 
     parseContext = {
         'logId' :logId,
@@ -392,7 +442,8 @@ def option_logs(args):
         'print_only_errors':error,
         'operation':None,
         'auto':auto,
-        'store_logId':store_logId
+        'store_logId':store_logId,
+        'search_dir':folder
     }
 
     if tail:
@@ -403,6 +454,9 @@ def option_logs(args):
     elif store:
         return debugLogs.do_parse_storage(parseContext)
 
+    elif is_folder:
+        return debugLogs.do_parse_storage(parseContext,search_dir=folder)
+
     elif inputfile != None:
         return debugLogs.do_parse_from_file(parseContext)
 
@@ -413,7 +467,7 @@ def option_logs(args):
         connectionInit(args)
         return debugLogs.do_parse_logs_lastN(parseContext)
 
-def option_h(args):
+def option_h(args,type="-h"):
 
     module = __import__('InCli')
 
@@ -422,10 +476,21 @@ def option_h(args):
 
     for f in functions:
         if f == 'option_h':      continue
-        args = '-h'
+        args = type
         p = eval(f'{f}(args)')
         if p != None: print(p)
 
+    print()
+    print()
+
+def option_hu(args):
+    if '-h' in args:
+        help = f"""
+        {utils.CYELLOW}-hu{utils.CEND} --> additional help for utilities. """
+        return help    
+
+    option_h(args,"-hu")
+
 def connectionInit(argsIn):
 
     userName_or_ofgAlias = getParam(argsIn,'-u') 
@@ -441,8 +506,11 @@ def checkVersion():
 
     try:
         restClient.init('ConnectionLess')
-        restClient.glog().info("Checking version")
+       # restClient.glog().info("Checking version")
         res = restClient.requestRaw(url='https://pypi.org/pypi/InCli/json')
+        if res == 'No Response':
+            print("No connection.")
+            return
         version = res['urls'][1]['filename'].split('-')[1].split('.tar')[0]
 
         if version != fileversion:
@@ -450,7 +518,7 @@ def checkVersion():
             print(f"Version {fileversion}. {colorama.Fore.WHITE+colorama.Back.RED}Version {version} is available --> pip install InCli --upgrade{utils.CEND}")
         else:
             print()
-            print(f"InCli version {fileversion} ")
+            print(f"{utils.CFAINT}InCli version {fileversion} {utils.CEND}")
     except Exception as e:
         print(e)
 
@@ -462,14 +530,16 @@ def _main(argsIn):
     restClient.glog().debug("In debug mode")
     checkVersion()
 
+
     if '-h' in argsIn:
         colorama.just_fix_windows_console()
 
         help = f"""
+
+
         {utils.CYELLOW}-readme{utils.CEND} --> new functionality added and some example. 
 
-        {utils.CYELLOW}-u{utils.CEND} --> username or org alias to be used to log into the org. 
-            {utils.CLIGHT_PURPLE}Defaultable u{utils.CEND}: Can be set to a default value --> {utils.CGREEN}InCli -default:set u "xx@adas.com {utils.CEND} """
+        {utils.CYELLOW}-u{utils.CEND} --> username or org alias to be used to log into the org. Used in most commands. {utils.CGREEN}InCli -u collote@acme.com ... {utils.CEND} or {utils.CGREEN}InCli -u orgAlias... {utils.CEND} """
         print(help)
 
     funcs = getmembers(sys.modules[__name__], isfunction)
@@ -492,6 +562,8 @@ def _main(argsIn):
     if '-h' in argsIn:
         print()
         print(utils.CBOLD+"SFDX Commands:"+utils.CEND)
+        print("InCli connects to the orgs as authorized in SFDX. Some useful commands are:")
+        print()
         print(f" - {utils.CYELLOW}sfdx force:org:list --verbose --all {utils.CEND}--> to list all authorized Orgs and Connection Status")
         print(f" - {utils.CYELLOW}sfdx auth:web:login -r 'Instance Url' -a 'Alias' {utils.CEND}--> to re-authorize")
         print(f" - {utils.CYELLOW}sfdx auth:web:login -u 'userName'  -a 'alias' {utils.CEND}--> to authorize and Org")
@@ -507,12 +579,15 @@ def main():
         print()
         print("ate ja")
     except Exception as e:
+        colorama.just_fix_windows_console()
+
         utils.printException(e)
        # print(traceback.format_exc())
 
         if "-debug" in sys.argv:
             print(traceback.format_exc())
 
+    print()
 if __name__ == '__main__':
     main()
 
