@@ -15,6 +15,7 @@ def getFieldList(objs,name):
     return [obj[name] for obj in objs]
 
 
+
 def Id(obj):
     if type(obj) is str:
         return obj
@@ -27,6 +28,14 @@ def Id(obj):
             id = id['value']
         return id
 
+def getF(objName,extendedF):
+    if extendedF == None:
+        return None
+    if type(extendedF) is dict:
+        extendedF = extendedF['Id']
+    ef = utils.extendedField(extendedF)
+    return query.query(f" select fields(all) from {objName} where {ef['field']} = '{ef['value']}' limit 200")
+
 def IdF(objName,extendedF,init=None):
     """Returns the Id for the especified extendedF in the form "fieldName:fieldValue" after querying SF.
     - In some cases the extendedF contains the Id itself and no query is required.
@@ -42,6 +51,7 @@ def IdF(objName,extendedF,init=None):
         return None
     if type(extendedF) is dict:
         extendedF = extendedF['Id']
+
     ef = utils.extendedField(extendedF)
     if ef['field'] == 'Id':
         if checkId(ef['value']):
@@ -160,6 +170,14 @@ def getSObjectType(id):
     return None
 #---------------------------------
 
+def get_with_only_id(Id):
+    objs= get_sobject_names_and_prefixes()
+    prefix = Id[0:3]
+    obj = [o for o in objs if o['keyPrefix'] == prefix][0]
+
+    res = get(id=Id,sobjectName= obj['name'])
+    return res
+
 def get(id,sobjectName=None):
     if sobjectName == None:
         sobjectName = getSObjectType(id)
@@ -170,10 +188,10 @@ def get(id,sobjectName=None):
 
 def create(sobjectname,object):
     call =  client.callAPI(f'/services/data/{apiVersion}/sobjects/{sobjectname}/', method="post", data=object) 
-    if client.lastThreadCall()['status_code'] == 201:
+    if client.thread_lastCall()['status_code'] == 201:
         logging.info(f"Object {sobjectname} created sucesfully. Id:{call['id']}")
     else:
-        logging.warning(f"Object {sobjectname} creation returned status code {client.lastThreadCall()['status_code']}")
+        logging.warning(f"Object {sobjectname} creation returned status code {client.thread_lastCall()['status_code']}")
         logging.warning(f"Response {call}")
 
         raise ValueError(simplejson.dumps(call, indent=4))
@@ -182,9 +200,9 @@ def create(sobjectname,object):
     return call
 
 def checkError():
-    lc = client.lastThreadCall()
+    lc = client.thread_lastCall()
     if lc['status_code'] >= 400:
-        logging.error(f"Error in call.  statusCode->{client.lastThreadCall()['status_code']}")
+        logging.error(f"Error in call.  statusCode->{client.thread_lastCall()['status_code']}")
         message = {
             'error':lc['error'],
             'errorCode':lc['errorCode']
@@ -216,8 +234,18 @@ def checkError():
                 utils.raiseException(obj['a'][0]['errorCode'],obj['a'][0]['message'])
         utils.raiseException(lc['errorCode'],lc['error'])
 
-def deleteMultiple(sobjectname,id): 
-    idList = ",".join(id)
+def deleteMultiple(sobjectname,id_list): 
+    def divide_chunks(l, n):
+        for i in range(0, len(l), n):
+            yield l[i:i + n]
+    if len(id_list) == 0: return None
+    if len(id_list)>200:
+        id200s= list(divide_chunks(id_list,200))
+        for id200 in id200s:
+            res = deleteMultiple(sobjectname,id200)
+        return res
+
+    idList = ",".join(id_list)
     logging.debug(f"deleting {sobjectname} with Id {idList}")
     call = client.callAPI(f'/services/data/{apiVersion}/composite/sobjects?ids={idList}', method="delete")
     try:
@@ -310,3 +338,21 @@ def selectOwnedRecords(sobjName,ownerId):
     call = query.query(select)
 
     return call
+
+sobjs=[]
+def get_sobject_names_and_prefixes():
+    global sobjs
+    if len(sobjs) > 0:
+        return sobjs
+    action = '/services/data/v51.0/sobjects'
+    res = client.callAPI(action)
+
+    sobjs=[]
+    for obj in res['sobjects']:
+        if obj['keyPrefix'] != None:            
+            sobj= {
+                'name':obj['name'],
+                'keyPrefix':obj['keyPrefix']
+            }
+            sobjs.append(sobj)
+    return sobjs
\ No newline at end of file
