@@ -22,7 +22,7 @@ def printLogRecords(loguser=None,limit=50,whereClause=None):
 
     utils.printFormated(logs1,rename="LogLength%Len:DurationMilliseconds%ms:Application%App")
     return logs
-    
+
 def get_apexLog_records(logUserId=None,limit=50,whereClause=None):
     where = f" where {whereClause} " if whereClause != None else ''
     where = f" where logUserId='{logUserId}' " if logUserId is not None else where
@@ -51,30 +51,53 @@ def apexLog_record_to_string(logRecord):
     log = logRecord
     username = get_username_and_cache(log['LogUserId'])
 
-    logLine = f"""{utils.CFAINT}LOGDATA:    Id: {log['Id']}   LogUserId: {log['LogUserId']} {utils.CGREEN}({username}){utils.CEND}{utils.CFAINT}    Request: {log['Request']}  Operation: {utils.CGREEN}{log['Operation']}{utils.CEND}{utils.CFAINT}    lenght: {log['LogLength']}    duration:  {utils.CGREEN}{log['DurationMilliseconds']} {utils.CFAINT} {utils.CFAINT}
+    logLine = f"""{utils.CFAINT}LOGDATA:    Id: {log['Id']}   LogUserId: {log['LogUserId']} {utils.CGREEN}({username}){utils.CEND}{utils.CFAINT}    Request: {log['Request']}  Operation: {utils.CGREEN}{log['Operation']}{utils.CEND}{utils.CFAINT}    lenght: {log['LogLength']}    duration:  {utils.CGREEN}{log['DurationMilliseconds']} {utils.CEND} 
  {utils.CFAINT}LOGDATA:      startTime: {log['StartTime']}    app: {log['Application']}      status: {log['Status']}     location: {log['Location']}     requestIdentifier: {log['RequestIdentifier']}{utils.CEND}
     """     
     return logLine
 
-def do_parse_storage(pc):  
+def do_parse_storage(pc,search_dir=None):  
     if pc['store_logId'] != None:
-        pc['logId'] = pc['store_logId']
-        do_parse_logId(pc)
+       # pc['logId'] = pc['store_logId']
+        pc['filepath'] = f"{restClient.logFolder()}{pc['store_logId']}.log"
 
-    search_dir = restClient.logFolder()
+        do_parse_logId(pc)
+        return
+
+    if search_dir==None:
+        search_dir = restClient.logFolder()
 
     os.chdir(search_dir)
     files = filter(os.path.isfile, os.listdir(search_dir))
     files = [os.path.join(search_dir, f) for f in files] # add path to each file
     files.sort(key=lambda x: os.path.getmtime(x))
-    fileNames = [os.path.basename(f) for f in files]
-    fileNames = [f for f in fileNames if '.log' in f]
+    log_files = [f for f in files if '.log' in f]
+    fileNames = [os.path.basename(f) for f in log_files]
 
-    ids = [f.split('.')[0] for f in fileNames]
-    print(f"Parsing {len(ids)} files in {search_dir}")
+    print(f"Files to be parsed in the store {len(log_files)}")
+    file_dates = []
+
+    print(f"Ordering files by date...")
+
+    for log_file in log_files:
+        body = get_apexLog_body_from_file(log_file)
+        for line in body.splitlines():
+            if '|' in line:
+                _time = line.split(' ')[0]
+                file_dates.append({
+                    'time':_time,
+                    'file':log_file
+                })
+                break
+
+    newlist = sorted(file_dates, key=lambda d: d['time'])
+
+    sorted_log_file = [d['file'] for d in newlist]
+
+    print(f"Ordered.")
 
     try:
-        parse_apexlogs_by_Ids(ids,pc,printProgress=True,printNum=False)
+        parse_apexlogs_by_Ids_or_filepaths(pc,logIds=None,filepaths=sorted_log_file,printProgress=True,printNum=False,threads=0)
 
     except KeyboardInterrupt:
         print('Interrupted')
@@ -161,7 +184,7 @@ def do_parse_tail(pc):
                 greater = False
                 procesed.extend(logIds)
 
-                parse_apexlogs_by_Ids(logIds=logIds,pc=pc,raiseKeyBoardInterrupt=True)
+                parse_apexlogs_by_Ids_or_filepaths(logIds=logIds,pc=pc,raiseKeyBoardInterrupt=True)
 
                 time0 = logRecords[-1][timefield]
                 timez = time0.split('.')[0] + "Z"
@@ -191,6 +214,14 @@ def do_parse_logs_lastN(pc):
     loguser = pc['loguser']
     lastN = pc['lastN']
 
+    if loguser ==None:
+        loguser = restClient.getConfigVar('loguser')
+
+    if loguser == None:
+        print(f"{utils.CYELLOW}Getting logs for all users.{utils.CEND}")
+    else:
+        print(f"{utils.CYELLOW}Getting logs for {loguser}.{utils.CEND}")
+
     where = f" where {whereClause} " if whereClause is not None else ''
     where = f" where logUserId='{get_loguser_id(loguser)}' " if loguser is not None else where
 
@@ -199,14 +230,16 @@ def do_parse_logs_lastN(pc):
     logIds = query.queryFieldList(q)
     if logIds == None or len(logIds)==0:   utils.raiseException(errorCode='NO_LOG',error=f'No logs can be found. ',other=q)
 
-    parse_apexlogs_by_Ids(logIds,pc)
+    parse_apexlogs_by_Ids_or_filepaths(logIds= logIds,pc=pc)
     print_parsing_results(pc)
 
 def do_parse_from_file(parseContext):
-    parseContext['body'] = file.read(parseContext['filepath'])
+    set_apexlog_body_in_pc(parseContext)
+
+  #  parseContext['body'] = file.read(parseContext['filepath'])
     parseContext['operation'] = 'parsefile'
-    name = os.path.basename(parseContext['filepath']).split('.')[0]
-    parseContext['logId']=name
+ #   name = os.path.basename(parseContext['filepath']).split('.')[0]
+ #   parseContext['logId']=name
     context =  parse_apexlog_body(parseContext)
     print_parsed_lines_to_output(parseContext)
     return context
@@ -218,11 +251,11 @@ def do_parse_logId(parseContext):
 
     return context
 
-def parse_apexlogs_by_Ids(logIds,pc,raiseKeyBoardInterrupt=False,printProgress=False,threads=10,printNum=True):
-    def readBody(q):
+def parse_apexlogs_by_Ids_or_filepaths(pc,logIds=None,filepaths=None,raiseKeyBoardInterrupt=False,printProgress=False,threads=10,printNum=True):
+    def read_log_from_org(q):
       while True:
         Id = q.get()
-        get_apexLog_body_from_file_or_db(Id)
+        get_apexLog_body_from_file_otherwise_db(Id)
         restClient.glog().debug(f"Read body for Id {Id}")
         q.task_done()
 
@@ -231,22 +264,33 @@ def parse_apexlogs_by_Ids(logIds,pc,raiseKeyBoardInterrupt=False,printProgress=F
     if 'errors' not in pc:   pc['errors'] = []
     if 'queue'  not in pc:   pc['queue'] = None
 
-    if threads >0 and pc['queue'] == None:
-        pc['queue'] = Queue(maxsize=0)
-        for x in range(0,threads):
-            threading.Thread(target=readBody,args=(pc['queue'],), daemon=True).start()
-    if threads>0:
+    if filepaths != None:
+        threads = 0
+
+    if threads >0: 
+        if pc['queue'] == None:
+            pc['queue'] = Queue(maxsize=0)
+            for x in range(0,threads):
+                threading.Thread(target=read_log_from_org,args=(pc['queue'],), daemon=True).start()
         for logid in logIds:
             pc['queue'].put(logid)
             
     num = 0
-    for num,logId in enumerate(logIds):
+    items = filepaths if filepaths != None else logIds
+    for num,item in enumerate(items):
         if printProgress:
-            sys.stdout.write("\r%d%%" % int(100*num/len(logIds)))
+            sys.stdout.write("\r%d%%" % int(100*num/len(items)))
         try:
-            parsed={ 'logId':logId, 'status':'ok' }
+            if logIds!= None:
+                parsed={ 'logId':item, 'status':'ok' }
+                pc['logId'] = item
+                pc['filepath'] = None
+            else:
+                parsed={ 'file':os.path.basename(item), 'status':'ok' }
+                pc['filepath'] = item  
+                pc['logId'] = None
+             
             pc['parsed_Id_status'].append(parsed)
-            pc['logId'] = logId
             set_apexlog_body_in_pc(pc)
             parse_apexlog_body(pc)
             print_parsed_lines_to_output(pc)
@@ -289,16 +333,34 @@ def get_loguser_id(loguser):
     id = Sobjects.IdF('User',loguser)
     return id if id!= None else utils.raiseException('QUERY',f"User with field {loguser} does not exist in the User Object.") 
 
-def get_apexLog_body_from_file_or_db(logId):
+def get_apexLog_body_from_file(filename):
+    if file.exists(filename):
+        return file.read(filename)
+
+    return None
+
+def set_apexlog_body_in_pc(pc):
+    """if pc['filepath'] defined, reads from the file specified. Otherwiese logId needs to be set. 
+    """
+    if 'filepath' in pc and pc['filepath'] != None:
+        pc['logRecord'] = None
+        pc['body'] = get_apexLog_body_from_file(pc['filepath'])
+    else:
+        pc['logRecord'],pc['body'],pc['filepath'] = get_apexLog_body_from_file_otherwise_db(pc['logId'])
+    if pc['body'] == None :   utils.raiseException(errorCode='NO_LOG',error=f'The requested log <{pc["logId"]}> cannot be found. ')
+    if len(pc['body'])==0:    utils.raiseException(errorCode='NO_LOG',error=f'The body for the requested log <{pc["logId"]}> is empty. ')
+    
+def get_apexLog_body_from_file_otherwise_db(logId):
+    """Gets the log body for the provided logId from file (if exists) otherwise from the Org"""
     filename = f"{restClient.logFolder()}{logId}.log"
 
     if file.exists(filename) == True:
-        body = file.read(filename)
+        body = get_apexLog_body_from_file(filename)
 
-        if len(body)==0:
+        if body == None or len(body)==0:
             print("The file seems corrupted. Getting log from server.")
             file.delete(filename)
-            return get_apexLog_body_from_file_or_db(logId)
+            return get_apexLog_body_from_file_otherwise_db(logId)
         return None,body,filename
     else:
         logRecord,body = get_apexLog_record_and_body(logId) 
@@ -306,10 +368,6 @@ def get_apexLog_body_from_file_or_db(logId):
         save_to_store(logId,body)
         return logRecord,body,filename
 
-def set_apexlog_body_in_pc(pc):
-    pc['logRecord'],pc['body'],pc['filepath'] = get_apexLog_body_from_file_or_db(pc['logId'])
-    if pc['body'] == None :   utils.raiseException(errorCode='NO_LOG',error=f'The requested log <{pc["logId"]}> cannot be found. ')
-    if len(pc['body'])==0:    utils.raiseException(errorCode='NO_LOG',error=f'The body for the requested log <{pc["logId"]}> is empty. ')
 
 def save_to_store(logId,body):
     filename = f"{restClient.logFolder()}{logId}.log"
@@ -318,7 +376,7 @@ def save_to_store(logId,body):
 def delta(obj,field):
     return obj[field][1] - obj[field][0] if len(obj[field]) > 1 else 0
 
-def createContext():
+def createContext(lines):
     context = {
         'totalQueries' : 0,
         'timeZero':0,
@@ -347,6 +405,12 @@ def createContext():
     context['prevLevel'] = 0
     context['firstLineIn'] = True
     context['firstLineOut'] = True
+
+    context['parsedLines'] = []
+    context['openItemsList'] = []
+
+    context['lines'] = lines
+
     return context
 
 frequency = {}
@@ -355,35 +419,22 @@ def parse_apexlog_body(pc):
     if len(pc['body'])==0:    utils.raiseException(errorCode='NO_LOG',error=f'The body for the requested log <{pc["logId"]}> is empty. ')
 
     try:
-        context = createContext()
+        context = createContext(pc['body'].splitlines())
         pc['context'] = context
 
-        logData = pc['body']
-        context['lines'] = logData.splitlines()
-        debugList = []
-
-        context['parsedLines'] = debugList
-        context['openItemsList'] = []
-
         for num,line in enumerate(context['lines']):
             if context['firstLineIn'] == True:
                 if 'APEX_CODE' in line:
                     context['firstLineIn'] = False
                     levels = line.strip().split(' ')[1].replace(',','=').replace(';','  ')
                     levels = f"{utils.CFAINT}{levels}{utils.CEND}"
-                    obj = {
-                        'type':'LOGDATA',
-                        'output':levels
-                    }
-                    debugList.append(obj)
+                    obj = {  'type':'LOGDATA', 'output':levels  }
+                    context['parsedLines'].append(obj)
 
                     continue      
                 else:
-                    obj = {
-                        'type':'LOGDATA',
-                        'output':line
-                    }
-                    debugList.append(obj)
+                    obj = {    'type':'LOGDATA',   'output':line  }
+                    context['parsedLines'].append(obj)
                     continue
 
             chunks = line.split('|')
@@ -393,27 +444,16 @@ def parse_apexlog_body(pc):
                 continue
             if len(chunks[1])>30:
                 continue
+
             context['chunks'] = chunks
-
-            context['lenChunks'] = len(chunks)
-
+            context['chunks_lenght'] = len(chunks)
             context['line'] = line
-            context['num'] = num
-
-            #file://Users/uormaechea/Documents/Dev/python/InCliLib/.incli/logs/07L3O00000DhuITUAZ.log
+            context['line_index'] = num
 
             if len(chunks)>1 and chunks[1] in ['SYSTEM_MODE_ENTER','SYSTEM_MODE_EXIT','HEAP_ALLOCATE','STATEMENT_EXECUTE','VARIABLE_SCOPE_BEGIN','HEAP_ALLOCATE','SYSTEM_METHOD_ENTRY','SYSTEM_METHOD_EXIT','SOQL_EXECUTE_EXPLAIN','ENTERING_MANAGED_PKG','SYSTEM_CONSTRUCTOR_ENTRY','SYSTEM_CONSTRUCTOR_EXIT']:    continue
 
             if len(chunks)>1 and chunks[1] in ['VALIDATION_RULE','VALIDATION_FORMULA','VALIDATION_PASS','WF_RULE_FILTER','WF_RULE_EVAL_VALUE','STATIC_VARIABLE_LIST','CUMULATIVE_LIMIT_USAGE_END','CUMULATIVE_LIMIT_USAGE','FLOW_CREATE_INTERVIEW_BEGIN','FLOW_CREATE_INTERVIEW_END','TOTAL_EMAIL_RECIPIENTS_QUEUED','CUMULATIVE_PROFILING_BEGIN','CUMULATIVE_PROFILING','CUMULATIVE_PROFILING_END','EXECUTION_STARTED','EXECUTION_FINISHED'] : continue
 
-            element = chunks[1]
-            if len(element) > 30:
-                a=1
-     #       if element not in frequency:
-     #           frequency[element] = 1
-      #      else:
-       #          frequency[element] =  frequency[element] +1
-            if '|SYSTEM_MODE_EXIT|' in line:      nop=1
             if elementParser.parseVariableAssigment(context):      continue
             if elementParser.parseMethod(context):            continue
             if elementParser.parseSOQL(context)==True:        continue
@@ -444,11 +484,13 @@ def parse_apexlog_body(pc):
         raise e
 
 
-def escape_ansi(line):
-    ansi_escape =re.compile(r'(\x9B|\x1B\[)[0-?]*[ -\/]*[@-~]')
-    return ansi_escape.sub('', line)
+
 
 def print_parsed_lines_to_output(pc):
+    def escape_ansi(line):
+        ansi_escape =re.compile(r'(\x9B|\x1B\[)[0-?]*[ -\/]*[@-~]')
+        return ansi_escape.sub('', line)
+
     if 1==1:
         pc['context']['parsedLines'] = processRepetition(pc['context']['parsedLines'])
 
@@ -465,7 +507,16 @@ def print_parsed_lines_to_output(pc):
             sys.stdout = original_stdout 
 
         data = file.read(filename)
-        html = ansi2html.Ansi2HTMLConverter().convert(data)
+        converter = ansi2html.Ansi2HTMLConverter()
+     #   converter.
+        html = converter.convert(data)
+        html = html.replace('background-color: #000000;','background-color: #020b3b;')
+        html = html.replace('aa5500','ecec16')
+        html = html.replace('F5F1DE','8e8383')
+        html = html.replace('AAAAAA','FFFFFF')
+        html = html.replace('000316','3c3e48')
+        html = html.replace('aa0000','e41717')
+
         filename = f"{restClient.logFolder()}{logId}.html"
         file.write(filename,html)
         print(f"Html file: {filename}")
@@ -487,8 +538,12 @@ def print_parsed_lines(pc):
     if logId != None:  print(logId)
     print()
     if logId != None:  print(f"{utils.CFAINT}Parsing log Id {logId}    file: {restClient.logFolder()}{logId}.log{utils.CEND}")
+    elif pc['filepath'] != None:
+            print(f"file: {pc['filepath']}")
 
     firstLines = True
+
+    pc['new_print'] = True
     for num,parsedLine in enumerate(context['parsedLines']):
         if parsedLine['type'] == 'LOGDATA':
             print(parsedLine['output'])
@@ -505,7 +560,7 @@ def print_parsed_lines(pc):
             if '*** getQueries() ***' in parsedLine['output']:   continue
             if parsedLine['type'] == 'LIMIT':                    continue
 
-        print_parsed_line(pc,parsedLine)    
+        print_parsed_line(pc,parsedLine,num)    
     print()
 
 def isRep(all_loops,parsed_line_index,parsed_line,parsed_lines):
@@ -551,11 +606,11 @@ def isRep(all_loops,parsed_line_index,parsed_line,parsed_lines):
                 #for the last line in the chain, set time_exit to the very last in the loop
                 if len(parsed_line['timeStamp']) > 1 : 
                     parsed_line['timeStamp'][1] = parsed_lines[ parsed_line_index + (links-1) * link_lenght ]['timeStamp'][1]
-                return True,parsed_line
+                return True,True
 
-            else: return True,None
+            else: return True,False
 
-      return False,None
+      return False,False
 
 def processRepetition(parsed_lines):
 
@@ -567,27 +622,41 @@ def processRepetition(parsed_lines):
 
     new_parsed_lines = []
     for parsedLineNum,parsedLine in enumerate(parsed_lines):
-        isrepe, obj = isRep(all_loops,parsedLineNum,parsedLine,parsed_lines)
-        if isrepe == True and obj == None:   continue
+        is_loop, is_first_chain = isRep(all_loops,parsedLineNum,parsedLine,parsed_lines)
+        if is_loop == True and is_first_chain == False:   continue
         new_parsed_lines.append(parsedLine)
 
     return new_parsed_lines   
 
 def emptyString(context,size,char=' ',ident=None):
-    str = ''
+ #   str = ''
     if ident is None:   ident = context['ident']
     length = ident * size
-    for x in range(length):   str = str + char  
+    str = " "*length
+ #   for x in range(length):   str = str + char  
     return str       
 
-def print_parsed_line(pc,d):
+def get_parent_if_last_for_level(parsed_lines,parsed_line_index):
+    current = parsed_lines[parsed_line_index]
+    for index in range(parsed_line_index+1,len(parsed_lines)):
+        if parsed_lines[index]['ident'] == current['ident']:
+            return None
+        if parsed_lines[index]['ident'] < current['ident']:
+            i = 1
+            while True:
+                parent = parsed_lines[parsed_line_index-i]
+                if parent['ident'] < current['ident']:
+                    return parent
+                i = i + 1
+
+
+def print_parsed_line(pc,d,parsed_line_index):
     context = pc['context']
     Cinit = utils.CEND
 
-    if 'printing_started' not in pc:
-        pc['printing_started'] = True
-
-        print( f"Log time: {pc['context']['parsedLines'][3]['lines'][0].split(' ')[0]}")
+    if pc['new_print']:
+        pc['new_print'] = False
+        print( f"Log time: {pc['context']['parsedLines'][3]['lines'][0].split(' ')[0]} to {pc['context']['parsedLines'][-1]['lines'][0].split(' ')[0]}")
 
     if d['type'] == 'LIMITS':
         context['previousIsLimit'] = True
@@ -624,7 +693,7 @@ def print_parsed_line(pc,d):
     cpu_time_exit = int(d['CPUTime'][1]) if len(d['CPUTime']) >1 else ''
 
     time_stamp_entry = d['timeStamp'][0]
-    time_stamp_exit = d['timeStamp'][1] if len(d['timeStamp'])>1 else d['timeStamp'][0]
+    time_stamp_exit = d['timeStamp'][1] if len(d['timeStamp'])>1 else time_stamp_entry
 
     soql_total_queries_entry = d['totalQueries'][0]
     soql_total_queries_exit = d['totalQueries'][1] if len(d['SOQLQueries']) >1 else soql_total_queries_entry
@@ -632,20 +701,27 @@ def print_parsed_line(pc,d):
 
     cpu_time_elapsed = cpu_time_entry - int(context['previousCPUTime'])
 
-    if level == context['prevLevel']:  wait_time = d['timeStamp'][0] - context['prevTimes'][level][1]
-    if level >  context['prevLevel']:  wait_time = d['timeStamp'][0] - context['prevTimes'][context['prevLevel']][0]
-    if level <  context['prevLevel']:  wait_time = d['timeStamp'][0] - context['prevTimes'][level][1]
+    if level == context['prevLevel']:  wait_time = time_stamp_entry - context['prevTimes'][level][1]
+    if level >  context['prevLevel']:  wait_time = time_stamp_entry - context['prevTimes'][context['prevLevel']][0]
+    if level <  context['prevLevel']:  wait_time = time_stamp_entry - context['prevTimes'][level][1]
 
     if wait_time <0 and 'is_loop' in d:   
-        wait_time = d['timeStamp'][0] - context['prevTimes'][level][0]
+        wait_time = time_stamp_entry - context['prevTimes'][level][0]
 
     if 'totalLoopWait' in d:
         wait_time = d['totalLoopWait'] + wait_time
 
-    context['prevTimes'][level] = [d['timeStamp'][0],time_stamp_exit]
+    context['prevTimes'][level] = [time_stamp_entry,time_stamp_exit]
 
     wait_time = f"{wait_time/1000000:.0f}"
 
+    wait_time_exit = "0"
+    parent = get_parent_if_last_for_level( context['parsedLines'],parsed_line_index)
+    if parent != None:
+        if len(parent['timeStamp']) > 1:
+            wait_time_exit = parent['timeStamp'][1] - time_stamp_exit
+            wait_time_exit = f"{wait_time_exit/1000000:.0f}"
+
     context['prevLevel'] = level
 
     soql_queries_entry = int(d['SOQLQueries'][0])
@@ -688,15 +764,17 @@ def print_parsed_line(pc,d):
     if soql_queries_cmt_exit==0: soql_queries_cmt_exit=''
     if soql_total_queries_entry == 0: soql_total_queries_entry = ''
     if wait_time == "0":  wait_time =''
+    if wait_time_exit == "0":  wait_time_exit ='' 
+    else: wait_time_exit=f"-{wait_time_exit}"
     if soql_queries_cmt_entry == 0 : soql_queries_cmt_entry = ''
     if soql_queries_entry == 0 : soql_queries_entry = ''
 
-    time_stamp_entry = utils.CFAINT + f"{time_stamp_entry:12}" + utils.CEND
-    time_stamp_exit = utils.CFAINT + f"{time_stamp_exit:12}" + utils.CEND
+    time_stamp_entry = utils.CLIGHT_GRAY +utils.CFAINT+ f"{time_stamp_entry:12}" + utils.CEND
+    time_stamp_exit = utils.CLIGHT_GRAY +utils.CFAINT+ f"{time_stamp_exit:12}" + utils.CEND
 
-    s = utils.CFAINT + "|" + utils.CEND
+    s = utils.CLIGHT_GRAY +utils.CFAINT+  "|" + utils.CEND
     if context['firstLineOut'] == True:
-        valname = f"{'wait':>5} time query  Call Stack"
+        valname = f"{'wait':>5}     time query  Call Stack"
         print(f"{utils.CFAINT}{'time entry':^12}{s}{utils.CFAINT}{'time exit':^12}{s}{'ts':^8}{s}{'CPU':^6}{s}{'cpuD':^6}{s}{'Qt':^3}{s}{'Q':^3}{s}{'Qmp':^3}{s}{'Qe':^3}{s}{'type':^21}{s}{'line':^4}{s}{valname:50}")
         context['firstLineOut'] = False
 
@@ -705,7 +783,7 @@ def print_parsed_line(pc,d):
     else:
         et_color = utils.CWHITE + utils.CFAINT
 
-    output_string = utils.CYELLOW+utils.CFAINT+ f"{wait_time:>5}{identation}"+et_color+f"{element_time:>5}"+utils.CDARK_GRAY+f"{soql_total_queries_delta:>4}" +utils.CEND + Cinit +f"    {output_string}"
+    output_string = utils.CYELLOW+utils.CFAINT+ f"{wait_time:>5}{wait_time_exit:<4}{identation}"+et_color+f"{element_time:>5}"+utils.CDARK_GRAY+f"{soql_total_queries_delta:>4}" +utils.CEND + Cinit +f"    {output_string}"
 
     print(f"{time_stamp_entry:12}{s}{time_stamp_exit:12}{s}{time_ms:>8}{s}{cpu_time_entry:>6}{s}{cpu_time_elapsed:6}{s}{soql_total_queries_entry:>3}{s}{utils.CGREEN}{soql_queries_entry:>3}{utils.CEND}{s}{soql_queries_cmt_entry:>3}{s}{utils.CYELLOW}{(Qmct_estimate):>3}{utils.CEND}{s}{element_type_color}{element_type:21}{utils.CEND}{s}{apex_line_number:>4}{s}{output_string:50}"+utils.CEND)
 
