@@ -1,4 +1,4 @@
-from . import utils
+from . import utils,Sobjects
 
 def setTimes(context,line,obj=None,field=None,value=None,chunkNum=None,type=None):
     def addList(obj,field,val):
@@ -107,7 +107,7 @@ def getFromList(theList,field,value,endsWith=False,delete=True,startsWith=False)
     return None
 
 def is_in_operation(context,text,contains=False):
-    if context['lenChunks']<2: return False
+    if context['chunks_lenght']<2: return False
     if contains and text in context['chunks'][1]: return True
     elif context['chunks'][1] == text: return True
     return False
@@ -129,7 +129,16 @@ def parseWfRule(context):
     if is_in_operation(context,'WF_CRITERIA',contains=True):
         if 'BEGIN' in chunks[1]:
             obj = setTimes(context,line,type='WF_CRITERIA')
-            obj['nameId'] = chunks[2]
+
+            colon_split=chunks[2].split(':')
+            colon_space = colon_split[1].strip().split(' ')
+            obj['ObjectName'] = colon_split[0][1:]
+            obj['RecordName'] = colon_space[0]
+            if len(colon_space)>1:
+                obj['RecordID'] = colon_space[1]
+            else:
+                obj['RecordID'] = ""
+
             obj['rulename'] = chunks[3]
             obj['rulenameId'] = chunks[4]
             obj['output'] = obj['rulename']
@@ -140,7 +149,7 @@ def parseWfRule(context):
         if 'END' in chunks[1]:
             obj =decreaseIdent_pop_setFields(context,type='WF_CRITERIA',key='type',value='WF_CRITERIA')   
             obj['result'] = chunks[2]
-            obj['output'] = f"{obj['rulename']} --> {obj['result']}"
+            obj['output'] = f"{obj['ObjectName']}: {obj['rulename']} --> {obj['result']}"
             return True
   
     if is_in_operation(context,'WF_RULE_NOT_EVALUATED'):
@@ -157,7 +166,7 @@ def parseExceptionThrown(context):
     line = context['line']
     chunks = context['chunks']
 
-  #  if context['lenChunks']>1 and chunks[1] == 'EXCEPTION_THROWN':
+  #  if context['chunks_lenght']>1 and chunks[1] == 'EXCEPTION_THROWN':
     if is_in_operation(context,'EXCEPTION_THROWN'):
         obj = setTimes(context,line,type='EXCEPTION',field='output',value=chunks[3])
         context['exception'] = True
@@ -166,18 +175,18 @@ def parseExceptionThrown(context):
         context['parsedLines'].append(obj)
         context['file_exception'] = True
         next = 1
-        nextline = context['lines'][context['num']+next]
+        nextline = context['lines'][context['line_index']+next]
         while '|' not in nextline:
             if nextline != '':
                 obj = context['parsedLines'][-1].copy()
                 context['parsedLines'].append(obj)
                 obj['output'] = nextline
             next = next + 1
-            nextline = context['lines'][context['num']+next]
+            nextline = context['lines'][context['line_index']+next]
         return True
 
     if is_in_operation(context,'FATAL_ERROR'):
-   # if context['lenChunks']>1 and chunks[1] == 'FATAL_ERROR':
+   # if context['chunks_lenght']>1 and chunks[1] == 'FATAL_ERROR':
         obj = setTimes(context,line,type='EXCEPTION',field='output',value=chunks[2])
         context['exception'] = True
         context['exception_msg'] = obj['output']
@@ -185,14 +194,14 @@ def parseExceptionThrown(context):
         context['parsedLines'].append(obj)
         context['file_exception'] = True
         next = 1
-        nextline = context['lines'][context['num']+next]
+        nextline = context['lines'][context['line_index']+next]
         while '|' not in nextline:
             if nextline != '':
                 obj = context['parsedLines'][-1].copy()
                 context['parsedLines'].append(obj)
                 obj['output'] = nextline
             next = next + 1
-            nextline = context['lines'][context['num']+next]
+            nextline = context['lines'][context['line_index']+next]
         return True
 
     return False
@@ -212,16 +221,16 @@ def parseUserDebug(context):
             context['exception_msg'] = obj['output']
         obj['apexline'] = chunks[2][1:-1]
         context['parsedLines'].append(obj)
-        if context['num']<(len(context['lines'])-1):
+        if context['line_index']<(len(context['lines'])-1):
             next = 1
-            nextline = context['lines'][context['num']+next]
+            nextline = context['lines'][context['line_index']+next]
             while '|' not in nextline:
                 obj = context['parsedLines'][-1].copy()
                 context['parsedLines'].append(obj)
             #    obj['string'] = nextline
                 obj['output'] = nextline
                 next = next + 1
-                nextline = context['lines'][context['num']+next]
+                nextline = context['lines'][context['line_index']+next]
 
         if  obj['output'].startswith('*** getCpuTime() ***'):
             chs = chunks[4].split(' ')
@@ -266,7 +275,7 @@ def parseLimits(context):
         else:                             limitsNS = f"{limits}:"
 
         next = 1
-        nextline = context['lines'][context['num']+next]
+        nextline = context['lines'][context['line_index']+next]
         while '|' not in nextline:
             if 'SOQL queries' in nextline:
                 nlchunks = nextline.split(' ')
@@ -278,7 +287,7 @@ def parseLimits(context):
                 if int(context[f'{limitsNS}CPU time']) < int(nlchunks[5]):
                     context[f'{limitsNS}CPU time'] = nlchunks[5]
             next = next + 1
-            nextline = context['lines'][context['num']+next]
+            nextline = context['lines'][context['line_index']+next]
         return True
 
 def parseSOQL(context):
@@ -291,6 +300,20 @@ def parseSOQL(context):
         obj['apexline'] = chunks[2][1:-1]
 
         soql = obj['query'].lower()
+        ch_so = obj['query'].split("'")
+        if len(ch_so)>1:
+            posibles = ch_so[1::2]
+
+            ids = [posible for posible in posibles if Sobjects.checkId(posible) ]
+            idss = set(ids)
+            if len(idss)>0:
+                obj['where_ids'] = ",".join(idss)
+
+
+        obj['for_update'] = ' for update' in soql
+
+        if 'where' in soql:
+            soql = soql.split('where')[0]
         _from = soql.split(' from ')[-1].strip()
         _from = _from.split(' ')[0]
 
@@ -300,11 +323,14 @@ def parseSOQL(context):
         append_and_increaseIdent(context,obj,increase=False)
         return True
 
-    if context['lenChunks']>1 and chunks[1] == 'SOQL_EXECUTE_END':
+    if context['chunks_lenght']>1 and chunks[1] == 'SOQL_EXECUTE_END':
         context['totalQueries'] = context['totalQueries'] + 1
         obj = decreaseIdent_pop_setFields(context,type="SOQL",key='type',value='SOQL',decrease=False)
         obj['rows'] = chunks[3].split(':')[1]
-        obj['output'] = f"Select: {obj['from']} --> {obj['rows']} rows"
+        for_uptate = "for update" if obj['for_update'] else ""
+        ids = f"w:{obj['where_ids']}" if 'where_ids' in obj else ""
+        obj['output'] = f"Select {for_uptate}: {obj['from']} --> {obj['rows']} rows {utils.CFAINT}{utils.CYELLOW}{ids}{utils.CEND}"
+
         return True
 
     return False
@@ -312,7 +338,7 @@ def parseSOQL(context):
 def parseMethod(context):
     line = context['line']
     chunks = context['chunks'] 
-    if context['lenChunks']>1 and 'METHOD_' in  chunks[1]:
+    if context['chunks_lenght']>1 and 'METHOD_' in  chunks[1]:
         if len(chunks)<4:
             print(line)
             return
@@ -376,11 +402,11 @@ def parseVariableAssigment(context):
             obj = setTimes(context,line,type='VAR_ASSIGN')
             obj['type'] = 'VAR_ASSIGN'
             obj['subType'] = 'EXCEPTION'
-            obj['string'] = chunks[4]
+         #   obj['string'] = chunks[4]
             obj['apexline'] = chunks[2][1:-1] if chunks[2]!='[EXTERNAL]' else 'EX'
 
             context['parsedLines'].append(obj)         
-            obj['output'] = obj['string'] 
+            obj['output'] = chunks[4]
 
         else:   context['EXP_VAR'] = False
         return False #why False???
@@ -410,8 +436,9 @@ def parseDML(context):
         obj['OP'] = chunks[3]
         obj['Type'] = chunks[4]
         obj['Id'] = chunks[2]
+        obj['Rows'] = chunks[5]
         obj['apexline'] = chunks[2][1:-1]
-        obj['output'] = f"{obj['OP']} {obj['Type']}" 
+        obj['output'] = f"{obj['OP']} {obj['Type']} --> {obj['Rows']}" 
         append_and_increaseIdent(context,obj)
         return True
 
@@ -427,11 +454,11 @@ def parseCallOutResponse(context):
 
     if is_in_operation(context,'CALLOUT_RESPONSE'):
         obj = setTimes(context,line,type='CALLOUT')
-        obj['string'] = chunks[3]
+     #   obj['string'] = chunks[3]
         obj['apexline'] = chunks[2][1:-1]
 
         context['parsedLines'].append(obj)  
-        obj['output'] = obj['string'] 
+        obj['output'] = chunks[3]
         return True
 
     return False
