@@ -320,4 +320,9 @@ def getNode(obj,path):
     return obj
 
 
+def replace_everywhere_in_obj(obj,find,replace):
+    strAll = simplejson.dumps(obj)
+    stItems2 = strAll.replace(find,replace)
+    return simplejson.loads(stItems2)
+
 
