@@ -4,10 +4,37 @@ from . import restClient as client
 from . import Sobjects,utils
 " select fields(all) from vlocity_cmt__EntityFilter__c where Id in ('a5W7Z0000009gEiUAI','a5W7Z0000009gdtUAA','a5W7Z0000009gFfUAI','a5W7Z0000009gEdUAI')"
 
-def _query(q,raiseEx=True,logResponse = False):
+def query_base64(q):
+    call = client.callAPI(f'/services/data/v55.0/query?q={q}')
+    if call['totalSize'] > len(call['records']):
+        len_max_records = len(call['records'])
+        q_order = f"{q} order by Id asc"
+        call = _query(q_order,nextRecords=False)
+        len_records_last_call = len(call['records'])
+        call_next = call
+        while (len_records_last_call==len_max_records):
+            lastId = call_next['records'][len_max_records-1]['Id']
+            q_and= f"{q} and Id>'{lastId}' order by Id asc"
+            call_next = _query(q_and,nextRecords=False)
+            call['records'].extend(call_next['records'])
+            len_records_last_call = len(call_next['records'])
+
+    return call
+
+
+def _query(q,raiseEx=True,logResponse = False,nextRecords=True,popAttributes=True):
     logging.debug(q)
     call = client.callAPI(f'/services/data/v55.0/query?q={q}')
-    lc = client.lastThreadCall()
+   # print(len(call['records']))
+
+    call_next = call
+    if nextRecords:
+        while 'nextRecordsUrl' in call_next:
+            call_next = client.callAPI(call_next['nextRecordsUrl'])
+          #  print(len(call_next['records']))
+            call['records'].extend(call_next['records'])
+
+    lc = client.thread_lastCall()
 
     lc['query']=q
     if lc['error'] != None:
@@ -22,6 +49,7 @@ def _query(q,raiseEx=True,logResponse = False):
 
     if logResponse == True:
         utils.printJSON(call)
+    for r in call['records']: r.pop('attributes')
 
     return call
 
