@@ -8,47 +8,64 @@ import simplejson as json
 _initializedConnections = []
 _allThreadsContext = {}
 _currentConnectionName = None
-def _threadContext(setConnectionName=None):
+
+def _create_thread_context(connection_name):
+    global _currentConnectionName
+    _currentConnectionName = connection_name if connection_name != None else _currentConnectionName
+    if _currentConnectionName == None:
+        utils.raiseException('ConnectionError',"Current Connection is no set.")
+    th = {
+            'connectionName': _currentConnectionName,
+            'calls':[]
+        }
+    _allThreadsContext[threading.get_native_id()] = th
+
+    return th
+
+def _get_thread_context(setConnectionName=None):
     """
     Threads can share a connection. However the call stack belongs to each thread.
     When a thread calls this function, it can set the connection for the thread (if especified) or get the connection previously set if setConnectionName=None
     If a connection has not been set fot the thread, the current one (the latest one set for any previous thread) is assigned to the thread   
     """
     global _allThreadsContext,_currentConnectionName
-    id = threading.get_native_id()
-    if id not in _allThreadsContext:
-        _currentConnectionName = setConnectionName if setConnectionName != None else _currentConnectionName
-        if _currentConnectionName == None:
-            utils.raiseException('ConnectionError',"Current Connection is no set.")
-        th = {
-            'connectionName': _currentConnectionName,
-            'calls':[]
-        }
-        _allThreadsContext[id] = th
-        return th
+    thread_id = threading.get_native_id()
+    if thread_id not in _allThreadsContext:
+    #    _currentConnectionName = setConnectionName if setConnectionName != None else _currentConnectionName
+    #    if _currentConnectionName == None:
+    #        utils.raiseException('ConnectionError',"Current Connection is no set.")
+        return _create_thread_context(setConnectionName)
+
+     #   _allThreadsContext[thread_id] = th
+     #   return th
     if setConnectionName != None:   #change the connection for the thread
-        _allThreadsContext[id]['connectionName'] = setConnectionName
+        _allThreadsContext[thread_id]['connectionName'] = setConnectionName
         _currentConnectionName = setConnectionName
-    return _allThreadsContext[id]
+    return _allThreadsContext[thread_id]
 
 ##################################################################
 def _pushThreadCall(call):
-    _calls = _threadContext()['calls']
-    if len(_calls) == 5:
+    max_calls = 5
+    _calls = _get_thread_context()['calls']
+    if len(_calls) == max_calls:
         _calls.pop(0)
     _calls.append(call)
 
 def _updateThreadCall(call):
-    _calls = _threadContext()['calls']
+    _calls = _get_thread_context()['calls']
     _calls[-1] = call
 
 def lastCall(field=None):
-    return lastThreadCall(field)
-def lastThreadCall(field=None):
+    return thread_lastCall(field)
+
+def thread_get_calls():
+    return _get_thread_context()['calls']
+
+def thread_lastCall(field=None):
     """
     Returns the last rest call data (request, response, others).
     """
-    _calls = _threadContext()['calls']
+    _calls = _get_thread_context()['calls']
     if field == None:
         return _calls[-1]
     return _calls[-1][field]
@@ -56,25 +73,34 @@ def lastThreadCall(field=None):
 def checklastThreadCallError(caller):
     """
     Raises and Exception if the last call has an error. """
-    lc = lastThreadCall()
+    lc = thread_lastCall()
     if 'error' in lc and lc['error'] is not None:
         utils.raiseException(lc['errorCode'],lc['error'],caller)
 
-def getLastCallTimes():
-    t = lastThreadCall()
-    et = t['elapsedTime']
-    delta = t['deltaTime']
+def get_call_times(call):
+    et = call['elapsedTime']
+    delta = call['deltaTime']
     times = {
         'elapsed':(et.microseconds + et.seconds * 1000000 )/1000,
         'delta':(delta.microseconds + delta.seconds * 1000000 )/1000,
     }
-    return times
-def getLastCallTime():
-    return getlastThreadCallTime()
-def getlastThreadCallTime():
-    t = lastThreadCall('elapsedTime')
-    return (t.microseconds + t.seconds * 1000000 )/1000
+    return times 
+def getLastCallTimes():
+    t = thread_lastCall()
+  #  et = t['elapsedTime']
+  #  delta = t['deltaTime']
+  #  times = {
+  #      'elapsed':(et.microseconds + et.seconds * 1000000 )/1000,
+  #      'delta':(delta.microseconds + delta.seconds * 1000000 )/1000,
+  #  }
+    return get_call_times(t)
 
+def getLastCallTime():
+    return thread_lastCall_time()
+
+def thread_lastCall_time():
+    t = thread_lastCall('elapsedTime')
+    return (t.microseconds + t.seconds * 1000000 )/1000
 
 def getConfigOrgsNames():
     """
@@ -198,7 +224,7 @@ def setConfigFile(configFile):
 sfdx_lock = threading.Lock()
 ####CONECTION
 def init(userName_or_orgAlias,connectionName=None):
-    if userName_or_orgAlias  != 'ConnectionLess':
+    if userName_or_orgAlias  != 'ConnectionLess' and userName_or_orgAlias != None:
         glog().info(f"Initializing connection for {userName_or_orgAlias}")
     if userName_or_orgAlias == 'ConnectionLess':
         _initMain(userName_or_orgAlias,None)
@@ -208,9 +234,9 @@ def init(userName_or_orgAlias,connectionName=None):
         if userName_or_orgAlias == None:
             userName_or_orgAlias = getConfigVar('u')
             if userName_or_orgAlias == None:
-                utils.raiseException('Configuration',"No userName or Org Alias specified. Please specify a user name or org alias.")
+                utils.raiseException('Configuration',f"No userName or Org Alias specified. Please specify a user name or org alias -> InCli -u orgAlias ...")
             inConf = True    
-            glog().info(f"Using default connection, {userName_or_orgAlias}.")
+            print(f"{utils.CFAINT}Using default connection,{utils.CEND}{utils.CGREEN} {userName_or_orgAlias}.{utils.CEND}")
 
         connectionName = connectionName if connectionName is not None else userName_or_orgAlias
         if _checkAndSetConnectionIfExists(connectionName):
@@ -221,8 +247,6 @@ def init(userName_or_orgAlias,connectionName=None):
             success,obj,outputs = utils.execute_force_org_display(userName_or_orgAlias)
             glog().debug(f"post sfdx")
 
-     #       success,outputs = utils.executeCommandParse(["sfdx","force:org:display","-u", userName_or_orgAlias])
-
         except Exception as e:
             if e.strerror == 'No such file or directory':
                 utils.raiseException('SFDXError',"SFDX is not installed or it is not accesible.",other='https://developer.salesforce.com/docs/atlas.en-us.sfdx_setup.meta/sfdx_setup/sfdx_setup_install_cli.htm')
@@ -237,10 +261,6 @@ def init(userName_or_orgAlias,connectionName=None):
             else:
                 utils.raiseException('SFDX Error',error,other='')
 
-     #  obj  = {}
-     #   for output in outputs:
-     #       obj[output['KEY']] = output['VALUE']
-
         if obj['Connected Status'] != 'Connected':
             utils.raiseException("ConnectionStatus",f"Connected Status for client Id {userName_or_orgAlias} is {obj['Connected Status']}",other=f"Execute the following command to refresh the token.  -")
 
@@ -293,7 +313,7 @@ def initWithConfig(orgName,isGuest=False,connectionName=None)->Boolean:
 def _checkAndSetConnectionIfExists(connectionName):
     for con in _initializedConnections:
         if con['connectionName'] == connectionName:
-            _threadContext(connectionName)
+            _get_thread_context(connectionName)
             if connectionName != 'ConnectionLess':
                 glog().info(f"Connection {connectionName} set.")
             return True
@@ -321,16 +341,20 @@ def _initMain(name,url,token=None,input=None,output=None,debug=None,username=Non
     if username != None:
         connection['username'] = username
     _initializedConnections.append(connection)
-    _threadContext(connection['connectionName'])
+    _get_thread_context(connection['connectionName'])
     if name != 'ConnectionLess':
-        glog().info(f"Connection {connection['connectionName']} initialized for username {username}.")
+        if connection['connectionName'] == username:
+             print(f"{utils.CYELLOW}Connection {connection['connectionName']} initialized.{utils.CEND}")
+
+        else:
+            print(f"Connection {connection['connectionName']} initialized for username {username}.")
 
 def getCurrentThreadConnection():
     """
     Retrieves the connectionParams for the current org. 
     """
     global _initializedConnections
-    connectionName = _threadContext()['connectionName']
+    connectionName = _get_thread_context()['connectionName']
     if connectionName == None:
         utils.raiseException('ConnectionError',"No connection has been established for current thread.",other="Make sure the connection is established.")
     connection = [con for con in _initializedConnections if con['connectionName']==connectionName][0]
@@ -373,10 +397,10 @@ def _authenticate(login,isSandbox):
         'Content-type': 'application/x-www-form-urlencoded'
     }
     server = 'test' if isSandbox else 'login'
-    _threadContext('oauth2')
+    _get_thread_context('oauth2')
     call = requestRaw(url=f"https://{server}.salesforce.com/services/oauth2/token",method='post', parameters= login,headers=headers)
     
-    lc = lastThreadCall()
+    lc = thread_lastCall()
     if lc['error'] is not None:
         utils.raiseException(lc['errorCode'],lc['error'],other=lc['errorOther'])
 
@@ -523,32 +547,29 @@ def callAPI_multi(action,params={} , method = 'get', data = {},headers={}):
     while done==False:
         call = requestWithConnection(action,parameters = params,method=method, data=data, headers=headers)
 
-        totalElepsedTime = lastThreadCall('elapsedTime') + totalElepsedTime
+        totalElepsedTime = thread_lastCall('elapsedTime') + totalElepsedTime
         totalCalls = totalCalls + 1
 
-        if  call == None or lastThreadCall('status_code')>=300:
+        if  call == None or thread_lastCall('status_code')>=300:
             break
         
-        glog().debug(f"callAPI_multi: <{action}>  ts:{lastThreadCall('elapsedTime')}") 
+        glog().debug(f"callAPI_multi: <{action}>  ts:{thread_lastCall('elapsedTime')}") 
 
         #For chainable integration procedures
-        if 'IPResult' in call and 'vlcStatus' in call['IPResult'] and call['IPResult']['vlcStatus'] == 'InProgress':
+        if type(call) is dict and 'IPResult' in call and 'vlcStatus' in call['IPResult'] and call['IPResult']['vlcStatus'] == 'InProgress':
             data['input'] = "{}"
-            data['options'] = json.dumps({
-                'vlcMessage':None,
-                'vlcIPData':call['IPResult']['vlcIPData'],
-                'vlcStatus':'InProgress'
-            })
+            data['options'] = json.loads(data['options'])
+            data['options']['vlcIPData'] = call['IPResult']['vlcIPData']
+            data['options'] = json.dumps(data['options'])
+            print(call['IPResult']['vlcIPData'])
 
-
-        #For digital commerce
-        elif 'nexttransaction' in call and type(call)==dict:
+        elif type(call) is dict and 'nexttransaction' in call :
             multiTransactionKey = call['nexttransaction']['rest']['params']['multiTransactionKey']
             data['multiTransactionKey'] = multiTransactionKey  
         else:
             done = True
 
-    lc = lastThreadCall()
+    lc = thread_lastCall()
     lc['elapsedTime'] = totalElepsedTime
     lc['totalCalls'] = totalCalls    
     _updateThreadCall(lc)
@@ -581,7 +602,7 @@ def callSave(logFileName,logRequest=False,logReply=True,timeStamp=False,response
     request_filename = None
     response_filename = None
 
-    lc = lastThreadCall()
+    lc = thread_lastCall()
 
     if logRequest == True:
         fn = f'{filename}_req'
