@@ -14,6 +14,8 @@ class TimeStats:
     def time(self,field):
         self.time_record[field] = restClient.getLastCallTime()
     
+    def time_no(self,field,value):
+        self.time_record[field] = value
     def print(self):
         utils.printFormated(self.time_records)
 
