@@ -66,7 +66,7 @@ def executeCommand(command):
     else:
         list_files = subprocess.run(command,capture_output=True,text=True)
 
-    print(list_files.stderr)
+    print(f"{CFAINT}{list_files.stderr}{CEND}")
     return list_files
 
 def execute_force_org_display(userName_or_orgAlias):
@@ -170,6 +170,7 @@ def raiseException(errorCode,error,module=None,other=None):
     raise InCliError(error)
 
 def printException(exception):
+    print()
     print(type(exception).__name__)
     if type(exception) == InCliError:
         _str = exception.args[0]['json']
@@ -181,6 +182,7 @@ def printException(exception):
         _str = simplejson.dumps(error, indent=2)
     logging.error(_str)
 
+
 #----------------------------------------------------------------------------------------------------
 
 def throwOrLog(message,raiseEx=True,dumps=False):
@@ -482,61 +484,57 @@ def computeTimes(call,name,times,_type=None):
 
 def get_all_loops(objs,field):
 
-    repeatingSequences = []
+    all_loops = []
     lastX = 0
-    if objs==None:
-        a=1
-    lenObj = len(objs)
+  #  if objs==None:
+  #      a=1
+ #   lenObj = len(objs)
     for x,val in enumerate(objs):
         if x <= lastX:    continue
-        firstdelta = None
+        loop_lenght = None
         lastDelta = 0
-        positions = []
-        if 'output' not in objs[x]:
-            oo = objs[x]
-        objx = objs[x]['output']
+        loop = []
+   #     if 'output' not in objs[x]:
+   #         oo = objs[x]
+   #     objx = objs[x]['output']
 
         max = 8
-        seq = False
+        is_loop = False
 
         for y in range(x+1,len(objs)):
-            if seq == False and y-x>=max:
+            if is_loop == False and y-x>=max:
                 break
-            if 'output' not in objs[y]:
-                oo = objs[y]
-            objy=objs[y]['output']
+     #       if 'output' not in objs[y]:
+     #           oo = objs[y]
+     #       objy=objs[y]['output']
 
-            if field not in objs[y]:
-                _o = objs[y]
+     #       if field not in objs[y]:
+     #           _o = objs[y]
             if 'ident' in objs[y] and 'ident' in objs[x] and objs[y]['ident'] == objs[x]['ident'] and objs[y][field] == objs[x][field]:
-                line = objs[y][field]
+      #          line = objs[y][field]
 
-                if firstdelta == None:
-                    firstdelta = y-x
-                    lastDelta = firstdelta
+                if loop_lenght == None:
+                    loop_lenght = y-x
+                    lastDelta = loop_lenght
                 else:   lastDelta = y - lastX
                 
-                seq = True
-                if lastDelta == firstdelta:
-                    for z in range(0,firstdelta):
-                        if y+z >= len(objs):
-                            seq=False
-                            break
-                        objz=objs[y+z]['output']
+                is_loop = True
+                if lastDelta == loop_lenght:
+                    for z in range(0,loop_lenght):
+                        if y+z >= len(objs): is_loop=False
+                        elif objs[y+z][field] != objs[x+z][field]: is_loop = False
 
-                        if objs[y+z][field] != objs[x+z][field]:
-                            seq = False
-                            break
-                    if seq == True:
-                        if len(positions) == 0:   positions.append(y-firstdelta)
-                        positions.append(y)
+                    if is_loop == False:   break
+                    if is_loop == True:
+                        if len(loop) == 0:   loop.append(y-loop_lenght)
+                        loop.append(y)
                 else:  break
-                if seq == True:     lastX = y 
+                if is_loop == True:     lastX = y 
 
-        if len(positions) > 0:  repeatingSequences.append(positions)
+        if len(loop) > 0:  all_loops.append(loop)
 
-    return repeatingSequences
-    print(repeatingSequences)
+    return all_loops
+    print(all_loops)
 
 def datetime_now_string(format = '%Y-%m-%dT%H:%M:%S%z',addMinutes=0):
     tz2 = datetime.now().astimezone()
