@@ -4,8 +4,8 @@ import simplejson,threading,time,multiprocessing,traceback,random,uuid,time,cale
 import InCli.InCli as incli
 
 procNum = 10
-threadNum = 40
-reps = 5
+threadNum = 20
+reps = 30
 guest_url = 'https://nosdti-parceiros.cs109.force.com/onboarding'
 def do_work(details):
   restClient.initWithToken('GUEST',url=guest_url)
@@ -13,6 +13,8 @@ def do_work(details):
   def getOffers(details):
 
     errors = 0
+    ts = timeStats.TimeStats()
+
     for x in range(0,reps):
       try:
         # cartId = '8017a000002ad21AAA'
@@ -23,18 +25,33 @@ def do_work(details):
         # digitalCommerce.createBasket('DC_CAT_WOO_MOBILE','C_WOO_MOBILE')
       #  val = f"{uuid.uuid4()}"
       #  print(val)
+        ts.new(["Basket","Error"])
         current_GMT = time.gmtime()
 
         val = calendar.timegm(current_GMT)
         offerDetails = digitalCommerceUtil.updateOfferField(details,'ATT_NOS_OTT_SUBSCRIPTION_ID','userValues',val,'code')
-        print("creating basket")
+        print("creating basket")        
         basket2 = digitalCommerce.createBasketAfterConfig('DC_CAT_WOO_MOBILE',offerDetails)
         print("got basket")
+        ts.time("Basket")
 
-        print(restClient.getLastCallTimes(),flush=True)
+        call1 = restClient.lastCall()
+        if call1['totalCalls'] >1:
+          calls = restClient.thread_get_calls()
+          times = restClient.get_call_times(call1)
+          times2 = restClient.get_call_times(calls[-2])
+          ts.time_no("Basket1",times2['delta'])
+          ts.time_no("Basket2",times['delta'])
+
+       #   print(f"{times2} {times}",flush=True)
+
+     #   print(restClient.getLastCallTimes(),flush=True)
       except Exception as e:
         utils.printException(e)
         errors = errors + 1
+        ts.time_no("Error","True")
+
+    ts.print()
       
     print(f"Processed {reps} with errors{errors}")  
      #   print(traceback.format_exc())
@@ -55,8 +72,6 @@ class Test_Query(unittest.TestCase):
         def do_process():
           restClient.initWithToken('GUEST',url=guest_url)
 
-        #  restClient.initWithToken('NOSQSM_Guest',url='https://sf-qms.nos.pt/onboarding')
-
           print("getting offer details")
           details = digitalCommerce.getOfferDetails('DC_CAT_WOO_MOBILE','C_WOO_MOBILE')
           print("got offer details")
@@ -72,7 +87,16 @@ class Test_Query(unittest.TestCase):
 
         do_process()
 
+    def test_query_apexlog(self):
+      restClient.init('DTI')
 
+      q = "select Operation,StartTime,DurationMilliseconds from Apexlog order by StartTime desc limit 200"
+      res = query.query(q)
+      for r in res['records']:
+        r.pop('attributes')
+
+      utils.printFormated(res['records'])
+      print()
     def test_createCart(self):
         restClient.init('NOSDEV')
 
@@ -446,38 +470,25 @@ class Test_Query(unittest.TestCase):
           return obj
 
         restClient.init('NOSDEV')
-        cartName = 'testa_2'
 
-        cartId = CPQ.getCartId(f"name:{cartName}")
-        if cartId != None:
-          CPQ.deleteCart(cartId)
+        accountname='unaiTest_1'
 
-        acc = account.createAccount('Name:unaiTest2',recordTypeName='Consumer')
-        cartId = CPQ.createCart(accountF= acc['Id'], pricelistF='Name:B2C Price List',name=cartName,checkExists=True)
-        print(restClient.getLastCallTime())
-
-        print(cartId)
-
-        promoName = 'NOS4u 100Mb + Móvel'
-        promo = CPQ.getCartPromotions(cartId,query=promoName,onlyOne=True)
-
-        res = CPQ.postCartsPromoItems_api(cartId,promo['Id'])
-        print(restClient.getLastCallTime())
+        cartId = self.create_cart_with_promo(accountname=accountname,cartName='testa_11',promoName='NOS4u 100Mb + Móvel',create=True,pricelistF='Name:B2C Price List')
 
         all = CPQ.getCartItems_api(cartId,fields='vlocity_cmt__ServiceAccountId__c,vlocity_cmt__BillingAccountId__c',price=False,validate=False,includeAttachment=False)
         print(restClient.getLastCallTime())
 
-        strAll = simplejson.dumps(all)
+        account1Id = account.getId(f'name:{accountname}')
+        account2Id = account.getId('name:unai2')
 
-        account1Id = account.getAccountId('name:unaiTest2')
-        account2Id = account.getAccountId('name:unai2')
+     #   strAll = simplejson.dumps(all)
+     #   stItems2 = strAll.replace(account1Id,account2Id)
+        items = objectUtil.replace_everywhere_in_obj(all,account1Id,account2Id)
 
-        stItems2 = strAll.replace(account1Id,account2Id)
-        items = simplejson.loads(stItems2)
         print(cartId)
 
         codes = ['C_NOS_SERVICE_TV_003','C_NOS_EQUIP_TV_006','C_NOS_EQUIP_TV_009','C_NOS_SERVICE_IF_001','C_NOS_EQUIP_GIGA_ROUTER','C_NOS_DN','C_NOS_SERVICE_VF_001','C_NOS_MSISDN','C_NOS_SERVICE_VM_001','C_NOS_EQUIP_SIM_CARD','C_NOS_OFFER_001','C_NOS_OFFER_006','C_NOS_AGG_SERVICE_TV_UMA','C_NOS_AGG_SERVICE_IF_HFC','C_NOS_AGG_SERVICE_VF_HFC','C_NOS_AGG_SERVICES_MAND_VM']
-      #  codes = ['C_NOS_OFFER_006']
+        codes = ['C_NOS_OFFER_006']
       #  codes = []
         lineItem = objectUtil.getSiblingWhere(items,selectKey='ProductCode',selectKeyValue='C_NOS_OFFER_001',whereKey='itemType',whereValue='lineItem')['object']
    #     for key in lineItem.keys():
@@ -513,6 +524,10 @@ class Test_Query(unittest.TestCase):
 
         incli._main(["-u","NOSDEV","-q", f"select Id,vlocity_cmt__BillingAccountId__c,vlocity_cmt__LineNumber__c,vlocity_cmt__ServiceAccountId__c,vlocity_cmt__Product2Id__r.productCode from orderitem where OrderId='{cartId}' order by vlocity_cmt__LineNumber__c","-fields","all"])  
 
+    def test_get_order_lines_for_CartId(self):
+        cartId = '8013O000003j97nQAA'
+        incli._main(["-u","NOSDEV","-q", f"select Id,vlocity_cmt__LineNumber__c,vlocity_cmt__Product2Id__r.productCode,vlocity_cmt__Product2Id__r.name from orderitem where OrderId='{cartId}' order by vlocity_cmt__LineNumber__c","-fields","all"])  
+
     def test_deleteOrder(self):
       orderId = '8013O000003a9CoQAI'
       restClient.init('NOSDEV')
@@ -525,7 +540,6 @@ class Test_Query(unittest.TestCase):
 
       restClient.init('NOSDEV')
       
-
     def create_cart_with_promo(self,accountname,cartName,promoName,create=False,pricelistF='Name:B2C Price List'):
 
         cartId = CPQ.getCartId(f"name:{cartName}")
@@ -535,13 +549,13 @@ class Test_Query(unittest.TestCase):
           CPQ.deleteCart(cartId)
 
         accountF = f'Name:{accountname}'
-        accountId = account.create_Id(accountF,recordTypeName='Consumer')
+        accountId = account.create_Id(accountname,recordTypeName='Consumer')
         cartId = CPQ.createCart(accountF= accountId, pricelistF=pricelistF,name=cartName,checkExists=True)
 
      #   promoName = 'NOS4u 100Mb + Móvel'
         promo = CPQ.getCartPromotions(cartId,query=promoName,onlyOne=True)
 
-        res = CPQ.postCartsPromoItems_api(cartId,promo['Id'])
+        res = CPQ.postCartsPromoItems_api(cartId,promo['Id'],price=False,validate=False)
 
         return cartId
 
@@ -701,7 +715,6 @@ class Test_Query(unittest.TestCase):
 
         print()
 
-
     def test_get_cart_items(seld):
         restClient.init('NOSQSM')
         restClient.setLoggingLevel()
@@ -720,9 +733,8 @@ class Test_Query(unittest.TestCase):
 
         print()
 
-
     def test_post_cart_items(self):
-        restClient.init('NOSQSM')
+        restClient.init('DTI')
         restClient.setLoggingLevel()
         pricelistF = "Name:B2C Price List"
 
