@@ -98,6 +98,14 @@ class Test_Main(unittest.TestCase):
             print(traceback.format_exc())
             self.assertTrue(1==2)
 
+    def test_hu(self):
+        try:
+            InCli._main(["-hu"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+
     def test_cc(self):
         try:
             InCli._main(["-u","NOSDEV","-cc"])
@@ -106,6 +114,15 @@ class Test_Main(unittest.TestCase):
             print(traceback.format_exc())
             self.assertTrue(1==2)
 
+    def test_cc_no_u(self):
+        try:
+            InCli._main(["-cc"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+
+
     def test_cc_basket(self):
         try:
             InCli._main(["-u","NOSQSM","-cc","-basket"])
@@ -148,7 +165,7 @@ class Test_Main(unittest.TestCase):
 
     def test_logs_store(self):
         try:
-            InCli._main(["-u","NOSDEV","-logs","-store"])
+            InCli._main(["-logs","-store"])
         except Exception as e:
             utils.printException(e)
             print(traceback.format_exc())
@@ -156,7 +173,7 @@ class Test_Main(unittest.TestCase):
 
     def test_logs_store_id(self):
         try:
-            InCli._main(["-u","NOSDEV","-logs","-store","07L3O00000Dic7oUAB"])
+            InCli._main(["-logs","-store","07L3O00000Dwi37UAB"])
         except Exception as e:
             utils.printException(e)
             print(traceback.format_exc())
@@ -202,7 +219,8 @@ class Test_Main(unittest.TestCase):
         try:
             res = InCli._main(["-u","NOSDEV","-logs","-loguser","Alias:xxxx"])
         except Exception as e:
-            self.assertTrue(e.args[0]['error']=='User with field Alias = xxxx does not exist in the User Object.')
+            print(e.args[0]['error'])
+            self.assertTrue(e.args[0]['error']=='User with field Alias:xxxx does not exist in the User Object.')
             utils.printException(e)
 
     def test_logs_limit(self):
@@ -216,7 +234,9 @@ class Test_Main(unittest.TestCase):
 
     def test_logs(self):
         try:
-            InCli._main(["-u","DTI","-logs"])
+            res = InCli._main(["-u","DTI","-logs"])
+            if len(res)>0:
+                self.assertTrue(res[0]['Id']!=None)
         except Exception as e:
             utils.printException(e)
             print(traceback.format_exc())
@@ -224,7 +244,8 @@ class Test_Main(unittest.TestCase):
    
     def test_logs_level(self):
         try:
-            InCli._main(["-u","NOSDEV","-logs","07L3O00000DjhX1UAJ","-level","1"])
+            res = InCli._main(["-u","NOSDEV","-logs","07L3O00000DjhX1UAJ","-level","1"])
+            print()
         except Exception as e:
             utils.printException(e)
             print(traceback.format_exc())
@@ -269,13 +290,61 @@ class Test_Main(unittest.TestCase):
             print(e)
             print(traceback.format_exc())
 
+#07L3O00000Dy7SAUAZ
     def test_log_ID(self):
         try:
-            InCli._main(["-u","NOSDEV","-logs","07L7a00000T0MTkEAN"])
+            InCli._main(["-u","NOSDEV","-logs","07L3O00000DyP4iUAF"])
         except Exception as e:
             print(e)
             print(traceback.format_exc())
 
+    def test_log_ID_limitsInfo(self):
+        try:
+            InCli._main(["-u","NOSDEV","-logs","07L3O00000DxlaLUAR","-limitinfo"])
+        except Exception as e:
+            print(e)
+            print(traceback.format_exc())
+    def test_log_ID_to_file(self):
+        try:
+            InCli._main(["-u","DTI","-logs","07L0Q00000N5yVKUAZ","-file"])
+        except Exception as e:
+            print(e)
+            print(traceback.format_exc())
+
+    def test_log_folder(self):
+        try:
+            res = InCli._main(["-logs","-folder",f"/Users/uormaechea/Downloads/logs_SF"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+
+    def test_log_folder_Id(self):
+        try:
+            res = InCli._main(["-logs","-folder",f"/Users/uormaechea/Downloads/logs_SF"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+
+    
+    def test_log_file(self):
+        try:
+            id = '07L0Q00000N5yVKUAZ'
+            res = InCli._main(["-logs","-inputfile",f"/Users/uormaechea/Downloads/logs_SF/apex-07L7T000003AWSiUAO.log"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+    def test_log_file_id(self):
+        try:
+            id = '07L0Q00000N5yVKUAZ'
+            res = InCli._main(["-logs","-inputfile",f"/Users/uormaechea/Documents/Dev/python/InCliLib/InCLipkg/.InCli/logs/{id}.log"])
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+
     def test_log_file_set_id(self):
         try:
             id = '07L3O00000DwvxvUAB'
@@ -296,7 +365,7 @@ class Test_Main(unittest.TestCase):
 
     def test_log_file_to_file(self):
         try:
-            restClient.init('NOSDEV')
+            restClient.init('DTI')
             html_name = f"{restClient.logFolder()}07L3O00000Dgt4sUAB.html"
             txt_name = f"{restClient.logFolder()}07L3O00000Dgt4sUAB.html"
 
@@ -340,7 +409,7 @@ class Test_Main(unittest.TestCase):
 
     def test_log_last(self):
         try:
-            InCli._main(["-u","NOSDEV","-logs","-last","10000"])
+            InCli._main(["-u","NOSDEV","-logs","-last","100"])
         except Exception as e:
             utils.printException(e)
             print(traceback.format_exc())
@@ -365,7 +434,7 @@ class Test_Main(unittest.TestCase):
     def test_log_tail_auto(self):
         try:
             #return
-            InCli._main(["-u","NOSQSM","-logs","-tail","-auto"])
+            InCli._main(["-u","NOSDEV","-logs","-tail","-auto"])
         except Exception as e:
             utils.printException(e)
             print(traceback.format_exc())
@@ -442,6 +511,14 @@ class Test_Main(unittest.TestCase):
             print(traceback.format_exc())
             self.assertTrue(1==2)
 
+    def test_default_get(self):
+        try:
+            InCli._main(["-default:get"])        
+        except Exception as e:
+            utils.printException(e)
+            print(traceback.format_exc())
+            self.assertTrue(1==2)
+
     def test_default_weird(self):
         try:
             InCli._main(["-h:","InCli","-default:set","u","NOSDEV"])
